!-----|--1--------2---------3---------4---------5---------6---------7-|
!      Ce sous-programme calcule l'aggregation des variables GRISLI
!       Nord sur la grille ECBilt
!
!      Auteur : Didier M. Roche
!      Date   : 21 juillet 2008
!      Derniere modification : 17 juin 2009, Didier M. Roche
!      Last Modification: 27 July 2011, Marianne Bugelmayer
!-----|--1--------2---------3---------4---------5---------6---------7-|

       SUBROUTINE Interp_GRISLI2L

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Variables d'entree  : 
!       Variables de sortie : 
!-----|--1--------2---------3---------4---------5---------6---------7-|
#include 'choixcomposantes.h'

       USE taillesGrilles, ONLY: GNX, GNY, iEcb, jEcb, CNX, CNY
!       Module contenant les definitions de la grille ECBilt
       USE output_ECBilt, ONLY: masqueECB, topoECB,                     &
          mxtopDifECB, mntopDifECB, masqueISM2ECB, modiffractn

!!!       Module contenant les definitions de la grille CLIO
!!        USE output_CLIO

!       Module contenant les definitions de la grille GRISLI Nord
       USE input_GRISLI2L, ONLY: topoGRIS, masqueGRIS, epaisglaceGRIS   &
                            ,iEGr, jEGr, nivo_mer, topoGRIS_sansnivomer &
                            ,calvGRIS,iCLIO,jCLIO,runoflGRIS,runoGRIS   &
                            ,ablbordGRIS2,abltopCLIO                    &
                            ,ablbordCLIO
#if ( WATGRISCONS == 1 )   
        USE runoff_coupl, ONLY : runoflECB, runoECB
        USE icb_coupl, ONLY: ocn_mask
#endif
!       Module that contains the definitions for the iceberg coupling
#if (CALVFLUX >= 1) 
       USE icb_coupl, ONLY: ocn_mask, calvCLIO
#endif


       IMPLICIT NONE
!       Ajout des interfaces pour les subroutines a parametres
!       optionnels
#include "aggregISM2ECB_interface.f90"
#include "aggregISM2CLIO_interface.f90"


! cdmr TEMPORAIRE
       INTEGER :: i,n,ii,jj
       REAL, DIMENSION(GNX,GNY) :: topoGRISLItemporaire
#if ( WATGRISCONS == 1 )  
       REAL :: sumruno, sumcalv
       REAL :: constest_tot, constest_run
#endif
!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Creation de la variable topoGRIS avec modif nivo des mers
!-----|--1--------2---------3---------4---------5---------6---------7-|

       topoGRIS = max(topoGRIS_sansnivomer - nivo_mer,0.0)



!-----|--1--------2---------3---------4---------5---------6---------7-|
!       In the case of RUNOFFGRIS, if ice-sheet shrinks we need to 
!       know where the ice WAS at previous timestep
!-----|--1--------2---------3---------4---------5---------6---------7-|

!#if (WATERCONSERVGRIS == 1)
!      call calculvol(DBLE(epaisglaceGRIS),icevol_GRIS)
!#endif
!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Creation du masque glaciaire sur grille GRISLI
!-----|--1--------2---------3---------4---------5---------6---------7-|

      CALL creationMasqueGRISLI(DBLE(epaisglaceGRIS),masqueGRIS,GNX,GNY)


!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Aggregation du masque
!-----|--1--------2---------3---------4---------5---------6---------7-|

       CALL aggregISM2ECB(masqueGRIS,GNX,GNY,masqueECB,iEcb, jEcb,      &
                          iEGr,jEGr,moyenne=1)


       CALL aggregISM2ECB(DBLE(topoGRIS),GNX,GNY,topoECB,iEcb,jEcb,     &
                     iEGr,jEGr,moyenne=1)

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Calcul des min/max de differences topoECB <-> topoGRIS 
!         par case ECBilt
!-----|--1--------2---------3---------4---------5---------6---------7-|

       mxtopDifECB = topoECB
       mntopDifECB = topoECB
      CALL topoDiffECBGRIS(DBLE(topoGRIS),GNX,GNY,mxtopDifECB,iEcb,jEcb,&
                     iEGr,jEGr,mntopDifECB)

!! La version simpliste ci-dessus ne fonctionne pas tout à fait à cause
!! de differences systematiques ...
!! Ajout d'un masque local definissant la terre de l'ISM dans ECB
       WHERE((ABS(mxtopDifECB).EQ.50000.).OR.(ABS(mntopDifECB).EQ.50000.&
            ))
         masqueISM2ECB = 0.0
       ELSEWHERE
         masqueISM2ECB = 1.0
       ENDWHERE

!! Puis on effectue le masquage
       mxtopDifECB = mxtopDifECB * masqueISM2ECB
       mntopDifECB = mntopDifECB * masqueISM2ECB


! ATTENTION ICI UN BRICOLAGE TEMPORAIRE ....

       DO i=1,GNX
        DO n=1,GNY

            jj = MIN(iEcb,FLOOR(jEGr(i,n)))
            ii = FLOOR(iEGr(i,n))

            topoGRISLItemporaire(i,n) = topoECB(jj,ii)

         ENDDO 
      ENDDO 

        open(1,file='outputdata/coupler/checktopoInterp.txt'            &
              ,form='formatted')
        DO i=1, GNX
           DO n=1, GNY
             write(1,'(2I5,12F15.3)') i,n,topoGRISLItemporaire(i,n)
           ENDDO
        ENDDO
        close(1)

! ATTENTION ICI UN BRICOLAGE TEMPORAIRE ....


# if(WATGRISCONS == 1) 
!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Aggregation du runoff (eau liquide sur la calotte)
!-----|--1--------2---------3---------4---------5---------6---------7-|
!mab: to only give the liquid runoff to ECBilt, not the calving too!!
!mab: have to take into account the conversion from ice to water
       sumruno = 0d0
       sumcalv = 0d0
       constest_tot = 0d0
       constest_run = 0d0

       runoflGRIS(:,:) = (runoGRIS(:,:) - calvGRIS(:,:))*0.910
        
       sumruno = sum(runoflGRIS(:,:))
       sumcalv = sum(calvGRIS(:,:))
       constest_tot = sum(runoflGRIS(:,:))/1E6/(86400.*360.)
       constest_run = (sum(runoGRIS(:,:))*0.910)/1E6/(86400.*360.)

       write(*,*)'sumrunoGRIS, sumcalvGRIS :'
       write(*,'(1pe10.3,1x,1pe10.3,1x,1pe10.3)') sum(runoGRIS(:,:))&
       ,sumcalv, sumruno     
       print*, 'runoffuncorr InterpGRISLI in SV :' &
       ,constest_tot,constest_run

!       runoff given to ECBilt given as flux (m3/timestep) is already in m3/yr
  
        
      CALL aggregISM2ECB(runoflGRIS,GNX,GNY,runoflECB,iEcb,jEcb,  &
                     iEGr,jEGr,moyenne=0)

#if (1)
       open(100,file='outputdata/ism/sumrunoffGRIS.txt', &
       form='formatted',access='append') 
!       form='formatted',status='replace') 
       write(100,'(3F25.10)') constest_run,constest_tot &
          ,(sum(calvGRIS(:,:))*0.910)/1E6/(86400.*360.)
       close(100)
# endif

#if (1)
     open(100,file='outputdata/ism/runoffGRIS.txt',form='formatted')    
      DO i=1, GNX
        DO n=1, GNY
         IF(runoflGRIS(i,n) .NE. 0D0) THEN
           write(100,'(2I5,12F25.10)') i,n,runoflGRIS(i,n)
         ENDIF
        ENDDO
      ENDDO
      close(100)
# endif

# endif

# if(CALVFLUX >= 1) 
!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Aggregation du calving (eau solide sur l'ocean)
!-----|--1--------2---------3---------4---------5---------6---------7-|

       CALL aggregISM2CLIO(calvGRIS,GNX,GNY,calvCLIO,CNX,CNY,           &
                     iCLIO,jCLIO,masque_oc=ocn_mask)
 
#if(1)
     open(100,file='outputdata/ism/calvGRIS.txt',form='formatted')    
      DO i=1, GNX
        DO n=1, GNY
         write(100,'(2I5,12F25.10)') i,n,(calvGRIS(i,n)/86400.*360.)
        ENDDO
      ENDDO
      close(100)
#endif

# endif
!-----|--1--------2---------3---------4---------5---------6---------7-|
!       OPTIONNEL : Verification des resultats par ecriture en grads
!-----|--1--------2---------3---------4---------5---------6---------7-|

      CALL output_grd2D(masqueECB,iEcb,jEcb,777,                        &
                            'outputdata/coupler/checkmasqueECB',1,0.0)
      CALL output_grd2D(topoECB,iEcb,jEcb,777,                          &
                            'outputdata/coupler/checktopoECB',1,0.0)

      CALL output_grd2D(mxtopDifECB,iEcb,jEcb,777,                      &
                            'outputdata/coupler/topoDiff1',1,0.0)
      CALL output_grd2D(mntopDifECB,iEcb,jEcb,777,                      &
                            'outputdata/coupler/topoDiff2',1,0.0)

!       CALL output_grd2D(runoTRA,iEcb,jEcb,777,'checkrunoTRA.dat',1)
!       CALL output_grd2D(calvCLIO,CNX,CNY,777,'checkcalvCLIO.dat',1)

! dmr ajout d une sortie de verification des cases a fraction de terre
! dmr modifiee dans ECBilt par le modele GRISLI
      CALL output_grd2D(modiffractn,iEcb,jEcb,777,                      &
                            'outputdata/globals/modiffractn',1,0.0)

       END SUBROUTINE Interp_GRISLI2L
