!-----|--1--------2---------3---------4---------5---------6---------7-|
!      Cette routine sert a aggreger les variables ISM de type "topo"
!       sur la grille du modele ECBilt
!       (dans l'environnement logiciel LUDUS)
!
!      Auteur : Masa Kageyama, Christophe Dumas
!      Date   : ? ? ?
!      Derniere modification : 21 juillet 2008, Didier M. Roche : 
!                              Portage de ISM2CLIMBER dans LUDUS
!-----|--1--------2---------3---------4---------5---------6---------7-|

      SUBROUTINE aggregISM2ECB(champi,nx,ny,champc,ex,ey,iGRID,jGRID,   &
                               masque,moyenne)

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Variables d'entree  : 
!        nx, ny   : taille du champ ISM
!        ex, ey   : taille du champ ECBilt
!        champi   : champ ISM
!        NB       : nombre de cases ISM sur le point de grille ECBilt
!                   considere
!        i(j)GRID : indices de correspondances ISM <-> ECBilt
!       Variables de sortie : 
!        champc   : champ ISM aggrege sur grille ECBilt
!-----|--1--------2---------3---------4---------5---------6---------7-|

      IMPLICIT NONE
      
      INTEGER, INTENT(IN) :: nx, ny, ex, ey

!      INTEGER, DIMENSION(ex,ey), INTENT(IN) :: NB
 
      REAL, DIMENSION(nx,ny), INTENT(IN)  :: champi, iGRID, jGRID
      REAL, DIMENSION(ex,ey), INTENT(INOUT) :: champc

      REAL, DIMENSION(nx,ny), INTENT(IN), OPTIONAL :: masque
      INTEGER, INTENT(IN), OPTIONAL :: moyenne




!-----|--1--------2---------3---------4---------5---------6---------7-|
!      Variables locales
!-----|--1--------2---------3---------4---------5---------6---------7-|

      INTEGER i,n, ii, jj
      INTEGER, DIMENSION(ex,ey) :: NB_lok


!-----|--1--------2---------3---------4---------5---------6---------7-|
!       Initialisation dans le cas ou l'on ne fait pas de min/max
!-----|--1--------2---------3---------4---------5---------6---------7-|

      champc = 0.
      NB_lok = 0

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       OPTION 1 : on calcule avec un masque si celui-ci est fourni
!-----|--1--------2---------3---------4---------5---------6---------7-|

      IF (PRESENT(masque)) THEN

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       OPTION 1a : calcul avec une moyenne ... (type topo) 
!-----|--1--------2---------3---------4---------5---------6---------7-|
      IF (PRESENT(moyenne).AND.(moyenne.EQ.1)) THEN
      DO i=1,nx
        DO n=1,ny

            jj = MIN(ex,FLOOR(jGRID(i,n)))
            ii = FLOOR(iGRID(i,n))

            IF (masque(i,n).GT.0.0) THEN
              champc(jj,ii) = champc(jj,ii) + champi(i,n)
              NB_lok(jj,ii) = NB_lok(jj,ii) + 1
            ENDIF

!            IF ((NB(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n))).ne.0)  &
!               .AND.(masque(i,n).GT.0.0)) THEN
!              champc(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n))) =     &
!              champc(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n)))       &
!          + champi(i,n) / FLOAT(NB(MIN(ex,FLOOR(iGRID(i,n))),           &
!              FLOOR(jGRID(i,n))))
!            ENDIF

         ENDDO 
      ENDDO 
             
      WHERE(NB_lok.NE.0) champc = champc / FLOAT(NB_lok)

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       OPTION 1b : calcul sans moyenne ... (type precipitation) 
!-----|--1--------2---------3---------4---------5---------6---------7-|
      ELSE
      DO i=1,nx
        DO n=1,ny

            jj = MIN(ex,FLOOR(jGRID(i,n)))
            ii = FLOOR(iGRID(i,n))

            IF (masque(i,n).GT.0.0) THEN
              champc(jj,ii) = champc(jj,ii) + champi(i,n)
            ENDIF

!            IF ((NB(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n))).ne.0)  &
!                 .AND.(masque(i,n).GT.0.0)) THEN
!              champc(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n))) =     &
!              champc(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n)))       &
!            + champi(i,n)
!            ENDIF

         ENDDO 
      ENDDO 
      ENDIF

!-----|--1--------2---------3---------4---------5---------6---------7-|
!       OPTION 2 : on calcule brutalement sans masque (aucun fourni)
!-----|--1--------2---------3---------4---------5---------6---------7-|
      ELSE 

      DO i=1,nx
        DO n=1,ny

            jj = MIN(ex,FLOOR(jGRID(i,n)))
            ii = FLOOR(iGRID(i,n))

!           WRITE(*,*) "dans aggreg", ii,jj,i,n

              champc(jj,ii) = champc(jj,ii) + champi(i,n)
              NB_lok(jj,ii) = NB_lok(jj,ii) + 1

!            IF (NB(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n))).ne.0) THEN
!              champc(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n))) =     &
!              champc(MIN(ex,FLOOR(iGRID(i,n))),FLOOR(jGRID(i,n)))       &
!          + champi(i,n) / FLOAT(NB(MIN(ex,FLOOR(iGRID(i,n))),           &
!              FLOOR(jGRID(i,n))))
!            ENDIF
         ENDDO 
      ENDDO 

      IF (PRESENT(moyenne).AND.(moyenne.EQ.1)) THEN
        WHERE(NB_lok.NE.0) champc = champc / FLOAT(NB_lok)
      ENDIF

!       open(100,file='outputdata/ism/sumAGGREGruno.txt', &
!       form='formatted',access='append') 
       write(*,*) 'in aggregISM2ECB: '
       write(*,'(1F25.10)') (sum(champc(:,:))/1d6/(86400.*360.))
!       close(100)
!      ENDIF

      ENDIF

      END SUBROUTINE aggregISM2ECB
